package com.demo.whousemywifi.routerInfo;

import android.content.Context;
import android.net.ConnectivityManager;
import android.net.DhcpInfo;
import android.net.NetworkInfo;
import android.net.wifi.WifiInfo;
import android.net.wifi.WifiManager;
import android.text.format.Formatter;
import java.math.BigInteger;
import java.net.Inet4Address;
import java.net.InetAddress;
import java.net.InterfaceAddress;
import java.net.NetworkInterface;
import java.net.SocketException;
import java.net.UnknownHostException;
import java.nio.ByteOrder;
import java.util.Enumeration;


public class Wireless {
    private Context context;

    public Wireless(Context context) {
        this.context = context;
    }

    public String getMacAddress() throws UnknownHostException, SocketException {
        String macAddress = getWifiInfo().getMacAddress();
        if ("02:00:00:00:00:00".equals(macAddress)) {
            byte[] hardwareAddress = NetworkInterface.getByInetAddress(getWifiInetAddress()).getHardwareAddress();
            StringBuilder sb = new StringBuilder();
            int length = hardwareAddress.length;
            for (int i = 0; i < length; i++) {
                sb.append(String.format("%02x:", Byte.valueOf(hardwareAddress[i])));
            }
            if (sb.length() > 0) {
                sb.deleteCharAt(sb.length() - 1);
            }
            return sb.toString();
        }
        return macAddress;
    }

    private InetAddress getWifiInetAddress() throws UnknownHostException {
        return InetAddress.getByName((String) getInternalWifiIpAddress(String.class));
    }

    public int getSignalStrength() {
        return getWifiInfo().getRssi();
    }

    public String getBSSID() {
        return getWifiInfo().getBSSID();
    }

    public String getGetWay() {
        return String.valueOf(Formatter.formatIpAddress(getWifiManager().getDhcpInfo().gateway));
    }

    public String getSSID() {
        String ssid = getWifiInfo().getSSID();
        return (ssid.startsWith("\"") && ssid.endsWith("\"")) ? ssid.substring(1, ssid.length() - 1) : ssid;
    }

    public <T> T getInternalWifiIpAddress(Class<T> cls) throws UnknownHostException {
        int ipAddress = getWifiInfo().getIpAddress();
        if (ByteOrder.nativeOrder().equals(ByteOrder.LITTLE_ENDIAN)) {
            ipAddress = Integer.reverseBytes(ipAddress);
        }
        byte[] byteArray = BigInteger.valueOf(ipAddress).toByteArray();
        if (cls.isInstance("")) {
            return cls.cast(InetAddress.getByAddress(byteArray).getHostAddress());
        }
        return cls.cast(Integer.valueOf(new BigInteger(InetAddress.getByAddress(byteArray).getAddress()).intValue()));
    }

    public int getInternalWifiSubnet() {
        DhcpInfo dhcpInfo;
        WifiManager wifiManager = getWifiManager();
        if (wifiManager == null || (dhcpInfo = wifiManager.getDhcpInfo()) == null) {
            return 0;
        }
        wifiManager.getConfiguredNetworks();
        int bitCount = Integer.bitCount(dhcpInfo.netmask);
        if (bitCount < 4 || bitCount > 32) {
            try {
                InetAddress wifiInetAddress = getWifiInetAddress();
                NetworkInterface byInetAddress = NetworkInterface.getByInetAddress(wifiInetAddress);
                if (byInetAddress == null) {
                    return 0;
                }
                for (InterfaceAddress interfaceAddress : byInetAddress.getInterfaceAddresses()) {
                    if (wifiInetAddress != null && wifiInetAddress.equals(interfaceAddress.getAddress())) {
                        return interfaceAddress.getNetworkPrefixLength();
                    }
                }
                return bitCount;
            } catch (SocketException | UnknownHostException unused) {
                return bitCount;
            }
        }
        return bitCount;
    }

    public int getNumberOfHostsInWifiSubnet() {
        return (int) (Math.pow(2.0d, 32.0d - Double.valueOf(getInternalWifiSubnet()).doubleValue()) - 2.0d);
    }

    public String getInternalMobileIpAddress() {
        try {
            Enumeration<NetworkInterface> networkInterfaces = NetworkInterface.getNetworkInterfaces();
            while (networkInterfaces != null && networkInterfaces.hasMoreElements()) {
                Enumeration<InetAddress> inetAddresses = networkInterfaces.nextElement().getInetAddresses();
                while (inetAddresses.hasMoreElements()) {
                    InetAddress nextElement = inetAddresses.nextElement();
                    if (!nextElement.isLoopbackAddress() && (nextElement instanceof Inet4Address)) {
                        return nextElement.getHostAddress();
                    }
                }
            }
            return "Unknown";
        } catch (SocketException unused) {
            return "Unknown";
        }
    }

    public int getLinkSpeed() {
        return getWifiInfo().getLinkSpeed();
    }

    public boolean isConnectedWifi() {
        NetworkInfo networkInfo = getNetworkInfo(1);
        return networkInfo != null && networkInfo.isConnectedOrConnecting();
    }

    public boolean isEnabled() {
        return getWifiManager().isWifiEnabled();
    }

    public WifiManager getWifiManager() {
        return (WifiManager) this.context.getApplicationContext().getSystemService(Context.WIFI_SERVICE);
    }

    public WifiInfo getWifiInfo() {
        return getWifiManager().getConnectionInfo();
    }

    private ConnectivityManager getConnectivityManager() {
        return (ConnectivityManager) this.context.getSystemService(Context.CONNECTIVITY_SERVICE);
    }

    private NetworkInfo getNetworkInfo(int i) {
        ConnectivityManager connectivityManager = getConnectivityManager();
        if (connectivityManager != null) {
            return connectivityManager.getNetworkInfo(i);
        }
        return null;
    }
}
